@@ -45,9 +45,6 @@ class _wrefsocket(_socket.socket):
 
     __slots__ = ("__weakref__", )
 
-_closedsocket = _wrefsocket()
-_closedsocket.close()
-
 
 class socket(object):
     """
@@ -238,7 +235,21 @@ class socket(object):
         self.hub.cancel_wait(self._read_event, cancel_wait_ex)
         self.hub.cancel_wait(self._write_event, cancel_wait_ex)
         _ss.close(self._sock)
-        self._sock = _closedsocket
+
+        # Break any references to the underlying socket object. Tested
+        # by test__refcount. (Why does this matter?). Be sure to
+        # preserve our same family/type/proto if possible (if we
+        # don't, we can get TypeError instead of OSError; see
+        # test_socket.SendmsgUDP6Test.testSendmsgAfterClose)... but
+        # this isn't always possible (see test_socket.test_unknown_socket_family_repr)
+        # TODO: Can we use a simpler proxy, like _socket2 does?
+        try:
+            self._sock = self._gevent_sock_class(self.family, self.type, self.proto)
+        except OSError:
+            pass
+        else:
+            _ss.close(self._sock)
+
 
     def close(self):
         # This function should not reference any globals. See Python issue #808164.
@@ -306,6 +317,27 @@ class socket(object):
                     raise
             self._wait(self._read_event)
 
+    if hasattr(_socket.socket, 'sendmsg'):
+        # Only on Unix
+
+        def recvmsg(self, *args):
+            while True:
+                try:
+                    return _socket.socket.recvmsg(self._sock, *args)
+                except error as ex:
+                    if ex.args[0] != EWOULDBLOCK or self.timeout == 0.0:
+                        raise
+                self._wait(self._read_event)
+
+        def recvmsg_into(self, *args):
+            while True:
+                try:
+                    return _socket.socket.recvmsg_into(self._sock, *args)
+                except error as ex:
+                    if ex.args[0] != EWOULDBLOCK or self.timeout == 0.0:
+                        raise
+                self._wait(self._read_event)
+
     def recvfrom(self, *args):
         while True:
             try:
@@ -388,6 +420,27 @@ class socket(object):
                     return 0
                 raise
 
+    if hasattr(_socket.socket, 'sendmsg'):
+        # Only on Unix
+        def sendmsg(self, buffers, ancdata=(), flags=0, address=None):
+            try:
+                return _socket.socket.sendmsg(self._sock, buffers, ancdata, flags, address)
+            except error as ex:
+                if flags & getattr(_socket, 'MSG_DONTWAIT', 0):
+                    # Enable non-blocking behaviour
+                    # XXX: Do all platforms that have sendmsg have MSG_DONTWAIT?
+                    raise
+
+                if ex.args[0] != EWOULDBLOCK or self.timeout == 0.0:
+                    raise
+                self._wait(self._write_event)
+                try:
+                    return _socket.socket.sendmsg(self._sock, buffers, ancdata, flags, address)
+                except error as ex2:
+                    if ex2.args[0] == EWOULDBLOCK:
+                        return 0
+                    raise
+
     def setblocking(self, flag):
         if flag:
             self.timeout = None
